tests.test_rationals module — justbases 0.07 documentation

### Navigation

- index
- modules |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »

# tests.test_rationals module

Test for rational conversions.

class `tests.test_rationals.` `RationalsTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Tests for rationals.

  `testExceptions`()

    Test exceptions.

  `testInverses`()

    Test that functions are inverses of each other.

  `testRounding`()

    Test rounding to int.

  `testRoundingConversion`()

    Test that converting and then rounding is the same as converting with rounding.

  `testRoundingExceptions`()

    Test exceptions.

  `testRoundingPrecise`()

    Test with predicted value.

### Navigation

- index
- modules |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »